rpy2: Python interface to R
===========================

Description
-----------

rpy2 is a redesign and rewrite of rpy. It is providing a low-level
interface to R, a proposed high-level interface, including wrappers to
graphical libraries, as well as R-like structures and functions.

License
-------

-  GPL 2+
-  Note that we have deleted references to Mozilla PL as an option,
   which we are allowed to do by the full rpy2 license in order to
   remain GPL-compatible


Upstream Contact
----------------

-  https://rpy2.bitbucket.io

Special Update/Build Instructions
---------------------------------

Patches
~~~~~~~

-  setup.patch: takes care of a few parsing issues.
-  cygwin.patch: let rpy2 build on Cygwin.
